@@ -50,26 +50,5 @@ class SingletonForEveryInitArgs(type):
         return cls._instances[tag]
 
 
-class EmptyPoolExecutor:
-    """伪造一个类似concurrent.futures.ThreadPoolExecutor、ProcessPoolExecutor的接口类
-        用来检查多线程、多进程中的错误
-
-    即并行中不会直接报出每个线程的错误，只能串行执行才好检查
-        但是两种版本代码来回修改很麻烦，故设计此类，只需把
-            concurrent.futures.ThreadPoolExecutor 暂时改为 EmptyPoolExecutor 进行调试即可
-    """
-
-    def __init__(self, *args, **kwargs):
-        """参数并不需要实际处理，并没有真正并行，而是串行执行"""
-        pass
-
-    def submit(self, func, *args, **kwargs):
-        """执行函数"""
-        func(*args, **kwargs)
-
-    def shutdown(self):
-        print('并行执行结束')
-
-
 if __name__ == '__main__':
     pass
